==> haskell-knob-0.1.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-knob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: knob
version: 0.1.1
id: knob-0.1.1-BMqK3hSPOz9mejkvDRIPI
key: knob-0.1.1-BMqK3hSPOz9mejkvDRIPI
license: MIT
maintainer: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/knob/
synopsis: Memory-backed handles
description:
    Create memory-backed '\''Handle'\''s, referencing virtual files. This is
    mostly useful for testing '\''Handle'\''-based APIs without having to
    interact with the filesystem.
    .
    > import Data.ByteString (pack)
    > import Data.Knob
    > import System.IO
    >
    > main = do
    >     knob <- newKnob (pack [])
    >     h <- newFileHandle knob "test.txt" WriteMode
    >     hPutStrLn h "Hello world!"
    >     hClose h
    >     bytes <- Data.Knob.getContents knob
    >     putStrLn ("Wrote bytes: " ++ show bytes)
category: System
author: John Millikin <jmillikin@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Knob
abi: fcbcf3d144f07dd3d2777ed58439f9eb
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/knob-0.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/knob-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/knob-0.1.1
hs-libraries: HSknob-0.1.1-BMqK3hSPOz9mejkvDRIPI
depends:
    base-4.10.0.0 bytestring-0.10.8.2 transformers-0.5.2.0
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
haddock-interfaces: /usr/share/doc/haskell-knob/html/knob.haddock
haddock-html: /usr/share/doc/haskell-knob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-knob-0.1.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-knob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: knob
version: 0.1.1
id: knob-0.1.1-4sPosrrSwNF5HdhEVGL5Jj
key: knob-0.1.1-4sPosrrSwNF5HdhEVGL5Jj
license: MIT
maintainer: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/knob/
synopsis: Memory-backed handles
description:
    Create memory-backed '\''Handle'\''s, referencing virtual files. This is
    mostly useful for testing '\''Handle'\''-based APIs without having to
    interact with the filesystem.
    .
    > import Data.ByteString (pack)
    > import Data.Knob
    > import System.IO
    >
    > main = do
    >     knob <- newKnob (pack [])
    >     h <- newFileHandle knob "test.txt" WriteMode
    >     hPutStrLn h "Hello world!"
    >     hClose h
    >     bytes <- Data.Knob.getContents knob
    >     putStrLn ("Wrote bytes: " ++ show bytes)
category: System
author: John Millikin <jmillikin@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Knob
abi: 52a3125b8530a932a2abbb7bec60507a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/knob-0.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/knob-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/knob-0.1.1
hs-libraries: HSknob-0.1.1-4sPosrrSwNF5HdhEVGL5Jj
depends:
    base-4.10.1.0 bytestring-0.10.8.2 transformers-0.5.2.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
haddock-interfaces: /usr/share/doc/haskell-knob/html/knob.haddock
haddock-html: /usr/share/doc/haskell-knob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
